@@ -2,14 +2,14 @@
 from __future__ import print_function
 
 import logging
-import os
-
 from subprocess import Popen, PIPE
 
-from acme.magic_typing import Set, List # pylint: disable=unused-import, no-name-in-module
+from acme.magic_typing import Set, List  # pylint: disable=unused-import, no-name-in-module
+
 from certbot import errors
 from certbot import util
-
+from certbot.compat import filesystem
+from certbot.compat import os
 from certbot.plugins import util as plug_util
 
 logger = logging.getLogger(__name__)
@@ -255,7 +255,7 @@ def execute(cmd_name, shell_cmd):
                      cmd_name, shell_cmd, cmd.returncode)
     if err:
         logger.error('Error output from %s command %s:\n%s', cmd_name, base_cmd, err)
-    return (err, out)
+    return err, out
 
 
 def list_hooks(dir_path):
@@ -267,5 +267,6 @@ def list_hooks(dir_path):
     :rtype: sorted list of absolute paths to executables in dir_path
 
     """
-    paths = (os.path.join(dir_path, f) for f in os.listdir(dir_path))
-    return sorted(path for path in paths if util.is_exe(path))
+    allpaths = (os.path.join(dir_path, f) for f in os.listdir(dir_path))
+    hooks = [path for path in allpaths if filesystem.is_executable(path) and not path.endswith('~')]
+    return sorted(hooks)
