@@ -4,30 +4,29 @@
 
 """
 import logging
-import os
-import pkg_resources
 import shutil
-import stat
+import sys
 import tempfile
 import unittest
-import sys
 from multiprocessing import Process, Event
 
-from cryptography.hazmat.backends import default_backend
-from cryptography.hazmat.primitives import serialization
-import mock
 import OpenSSL
 import josepy as jose
+import mock
+import pkg_resources
 import six
 from six.moves import reload_module  # pylint: disable=import-error
+from cryptography.hazmat.backends import default_backend
+from cryptography.hazmat.primitives import serialization
 
+from certbot import configuration
 from certbot import constants
 from certbot import interfaces
-from certbot import storage
-from certbot import configuration
 from certbot import lock
+from certbot import storage
 from certbot import util
-
+from certbot.compat import os
+from certbot.compat import filesystem
 from certbot.display import util as display_util
 
 
@@ -112,8 +111,7 @@ def skip_unless(condition, reason):  # pragma: no cover
         return unittest.skipUnless(condition, reason)
     elif condition:
         return lambda cls: cls
-    else:
-        return lambda cls: None
+    return lambda cls: None
 
 
 def make_lineage(config_dir, testfile):
@@ -140,7 +138,7 @@ def make_lineage(config_dir, testfile):
 
     for directory in (archive_dir, conf_dir, live_dir,):
         if not os.path.exists(directory):
-            os.makedirs(directory)
+            filesystem.makedirs(directory)
 
     sample_archive = vector_path('sample-archive')
     for kind in os.listdir(sample_archive):
@@ -265,13 +263,13 @@ class FreezableMock(object):
         if name in ('return_value', 'side_effect'):
             return setattr(self._mock, name, value)
 
-        else:
-            return object.__setattr__(self, name, value)
+        return object.__setattr__(self, name, value)
 
 
 def _create_get_utility_mock():
     display = FreezableMock()
-    for name in interfaces.IDisplay.names():  # pylint: disable=no-member
+    # Use pylint code for disable to keep on single line under line length limit
+    for name in interfaces.IDisplay.names():  # pylint: disable=no-member,E1120
         if name != 'notification':
             frozen_mock = FreezableMock(frozen=True, func=_assert_valid_call)
             setattr(display, name, frozen_mock)
@@ -295,7 +293,8 @@ def _create_get_utility_mock_with_stdout(stdout):
 
 
     display = FreezableMock()
-    for name in interfaces.IDisplay.names():  # pylint: disable=no-member
+    # Use pylint code for disable to keep on single line under line length limit
+    for name in interfaces.IDisplay.names():  # pylint: disable=no-member,E1120
         if name == 'notification':
             frozen_mock = FreezableMock(frozen=True,
                                         func=_write_msg)
@@ -317,7 +316,6 @@ def _assert_valid_call(*args, **kwargs):
     assert_kwargs['cli_flag'] = kwargs.get('cli_flag', None)
     assert_kwargs['force_interactive'] = kwargs.get('force_interactive', False)
 
-    # pylint: disable=star-args
     display_util.assert_valid_call(*assert_args, **assert_kwargs)
 
 
@@ -340,11 +338,7 @@ class TempDirTestCase(unittest.TestCase):
         logging.getLogger().handlers = []
         util._release_locks()  # pylint: disable=protected-access
 
-        def handle_rw_files(_, path, __):
-            """Handle read-only files, that will fail to be removed on Windows."""
-            os.chmod(path, stat.S_IWRITE)
-            os.remove(path)
-        shutil.rmtree(self.tempdir, onerror=handle_rw_files)
+        shutil.rmtree(self.tempdir)
 
 
 class ConfigTestCase(TempDirTestCase):
@@ -417,15 +411,6 @@ def skip_on_windows(reason):
     return wrapper
 
 
-def broken_on_windows(function):
-    """Decorator to skip temporarily a broken test on Windows."""
-    reason = 'Test is broken and ignored on windows but should be fixed.'
-    return unittest.skipIf(
-        sys.platform == 'win32'
-        and os.environ.get('SKIP_BROKEN_TESTS_ON_WINDOWS', 'true') == 'true',
-        reason)(function)
-
-
 def temp_join(path):
     """
     Return the given path joined to the tempdir path for the current platform
